Learn R Programming

dpasurv (version 0.1.0)

check.dag: Internal check of whether the formulas passed to the function dpa follow a directed acyclic graph (DAG)

Description

Do not call this function on its own

Usage

check.dag(meta, data)

Value

this function does not return anything, but throws an error with explanation if dag is not correctly specified

Arguments

meta

meta data obtained internally inside the dpasurv::dpa function

data

input data to the dpasurv::dpa function

Examples

Run this code
library(dpasurv)

data(simdata)

meta <- get.meta(Surv(start, stop, event) ~ x + M, list(M ~ x), simdata)
check.dag(meta, simdata)

Run the code above in your browser using DataLab