Learn R Programming

dpasurv (version 0.1.0)

Areg: Internal Aalen's Additive Hazards Model storing a linear effect estimate for each event time

Description

Do not call this function on its own

Usage

Areg(out.formula, id, data, method, ...)

Value

data.frame with observation times and estimated coefficients for independent variables in "regformula"

Arguments

out.formula

Survival formula for Aalen's additive hazards model.

id

character string indicating which column of 'data' corresponds to the subject ID.

data

Data set in counting process format. In particular the data should contain a "start", "stop" and "event" column along with any mediators and baseline covariates.

method

passed from dpa call, defaults to "timereg", otherwise "aareg"

...

other parameters passed to Aalen's additive hazards regression function "timereg::aalen()"

Examples

Run this code
library(dpasurv)

data(simdata)

obj <- Areg(Surv(start,stop,event)~M+x, id="subject", data=simdata, method="timereg")

Run the code above in your browser using DataLab