powered by
Do not call this function on its own
check.dag(meta, data)
this function does not return anything, but throws an error with explanation if dag is not correctly specified
meta data obtained internally inside the dpasurv::dpa function
input data to the dpasurv::dpa function
library(dpasurv) data(simdata) meta <- get.meta(Surv(start, stop, event) ~ x + M, list(M ~ x), simdata) check.dag(meta, simdata)
Run the code above in your browser using DataLab