get.meta: Internal function that gathers meta data on the input to function dpa
Description
Do not call this function on its own
Usage
get.meta(out.formula, mediator.formulas, data)
Value
list of meta data associated with out.formula and mediator.formulas. Consists of the following fields:
outcome
list containing variable names for startt, stopt, event, and right hand side of out.formula
mediator
list containing response variable name and right hand side of mediator.formulas
variables
list containing the class of variables in out.formula and mediator.formulas
Arguments
out.formula
Survival formula for Aalen's additive hazards model.
mediator.formulas
list of mediator regression formulas.
data
Data set in counting process format. In particular the data should contain a "start", "stop" and "event" column along with any mediators and baseline covariates.